@@ -1,11 +1,13 @@
 package defaultrolebindings
 
 import (
+	"context"
 	"fmt"
 	"time"
 
 	"k8s.io/apimachinery/pkg/api/errors"
 	"k8s.io/apimachinery/pkg/api/meta"
+	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/labels"
 	utilerrors "k8s.io/apimachinery/pkg/util/errors"
 	utilruntime "k8s.io/apimachinery/pkg/util/runtime"
@@ -124,7 +126,7 @@ func (c *DefaultRoleBindingController) syncNamespace(namespaceName string) error
 			continue
 		}
 
-		_, err := c.roleBindingClient.RoleBindings(namespaceName).Create(&desiredRoleBinding)
+		_, err := c.roleBindingClient.RoleBindings(namespaceName).Create(context.TODO(), &desiredRoleBinding, metav1.CreateOptions{})
 		if err != nil && !errors.IsAlreadyExists(err) {
 			errs = append(errs, err)
 		}
